==> org.apache.sling.event-3.2.0-sources.jar: org/apache/sling/event/impl/jobs/config/ConfigurationConstants.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.sling.event.impl.jobs.config;

/**
 * Constants for the queue configuration.
 */
public abstract class ConfigurationConstants {

    public static final int NUMBER_OF_PROCESSORS = Runtime.getRuntime().availableProcessors();

    public static final String DEFAULT_TYPE = "UNORDERED";
    public static final String DEFAULT_PRIORITY = "NORM";
    public static final int DEFAULT_RETRIES = 10;
    public static final long DEFAULT_RETRY_DELAY = 2000;
    public static final int DEFAULT_MAX_PARALLEL = 15;

    public static final String PROP_NAME = "queue.name";
    public static final String PROP_TYPE = "queue.type";
    public static final String PROP_TOPICS = "queue.topics";
    public static final String PROP_MAX_PARALLEL = "queue.maxparallel";
    public static final String PROP_RETRIES = "queue.retries";
    public static final String PROP_RETRY_DELAY = "queue.retrydelay";
    public static final String PROP_PRIORITY = "queue.priority";
}

==> org.apache.sling.event-3.3.6-sources.jar: org/apache/sling/event/impl/jobs/config/ConfigurationConstants.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.sling.event.impl.jobs.config;

/**
 * Constants for the queue configuration.
 */
public abstract class ConfigurationConstants {

    public static final int NUMBER_OF_PROCESSORS = Runtime.getRuntime().availableProcessors();

    public static final String DEFAULT_TYPE = "UNORDERED";
    public static final String DEFAULT_PRIORITY = "NORM";
    public static final int DEFAULT_RETRIES = 10;
    public static final long DEFAULT_RETRY_DELAY = 2000;
    public static final int DEFAULT_MAX_PARALLEL = 15;
    public static final boolean DEFAULT_KEEP_JOBS = false;
    public static final int DEFAULT_THREAD_POOL_SIZE = 0;

    public static final String PROP_NAME = "queue.name";
    public static final String PROP_TYPE = "queue.type";
    public static final String PROP_TOPICS = "queue.topics";
    public static final String PROP_MAX_PARALLEL = "queue.maxparallel";
    public static final String PROP_RETRIES = "queue.retries";
    public static final String PROP_RETRY_DELAY = "queue.retrydelay";
    public static final String PROP_PRIORITY = "queue.priority";
    public static final String PROP_KEEP_JOBS = "queue.keepJobs";
    public static final String PROP_THREAD_POOL_SIZE = "queue.threadPoolSize";

}
